# -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:ft=tcl:et:sw=4:ts=4:sts=4
# $Id: Portfile 139526 2015-08-19 20:45:46Z ryandesign@macports.org $

PortSystem          1.0

name                nethack
version             3.6.0
revision            1
categories          games
maintainers         nomaintainer
description         Classic dungeon adventure game.
long_description    ${description}
homepage            http://nethack.sourceforge.net/
platforms           darwin freebsd
license             Copyleft

master_sites        sourceforge
distname            ${name}-360-src
extract.suffix      .tgz
checksums           ${distfiles} md5 d42147b26e5fb4746fb72536ce145984 \
                    ${distfiles} sha1 a94aebcca367954595747ac468d095f12fbf993a \
                    ${distfiles} rmd160 2500e4d53682757b39883789281e4ae3395acb91

depends_lib         port:ncurses

worksrcdir          ${name}-${version}

patch.args          -p1
patchfiles          patch-sys__unix__Makefile.doc.diff \
                    patch-sys__unix__Makefile.src.diff \
                    patch-sys__unix__Makefile.top.diff \
                    patch-win__tty__termcap.c.diff

post-patch {
    reinplace "s|__PREFIX__|${prefix}|" \
        "${worksrcpath}/sys/unix/Makefile.doc" \
        "${worksrcpath}/sys/unix/Makefile.top"
}

configure.dir       ${worksrcpath}/sys/unix
configure.cmd       /bin/sh
configure.pre_args  setup.sh

build.args-append   CC=${configure.cc} \
                    CXX=${configure.cxx} \
                    CPP=${configure.cpp} \
                    CFLAGS="-O2 -I../include"

pre-destroot {
    file mkdir "${destroot}${prefix}/share/man/man6"
    file mkdir "${destroot}${prefix}/share/nethackdir/save"
}

destroot.target     install manpages
destroot.keepdirs   "${destroot}${prefix}/share/nethackdir/save/"

post-destroot {
    reinplace "s|${destroot}||" "${destroot}${prefix}/bin/nethack"

    # Don't overwrite existing preference files
    foreach f { logfile record } {
        file rename ${destroot}${prefix}/share/nethackdir/${f} ${destroot}${prefix}/share/nethackdir/${f}.dist
    }
}

post-activate {
    # Make sure initial preference files exist
    foreach f { logfile record } {
        if {![file exists ${prefix}/share/nethackdir/${f}]} {
            file copy ${prefix}/share/nethackdir/${f}.dist ${prefix}/share/nethackdir/${f}
        }
    }
}

variant x11 {
    patchfiles-append \
        x11/patch-include__config.h.diff \
        x11/patch-sys__unix__Makefile.src.diff \
        x11/patch-sys__unix__Makefile.top.diff
    depends_lib-append port:xorg-libXaw
}

#variant paranoid {
#        patch_sites-append http://www.netsonic.fi/~walker/nh/
#        patchfiles-append paranoid-343.diff
#        checksums-append paranoid-343.diff md5 ade00f9cb51f1b0140557d329d56844c
#}

#variant deathexplore {
#        patch_sites-append http://www.netsonic.fi/~walker/nh/
#        patchfiles-append dthexp-343.diff
#        checksums-append dthexp-343.diff md5 ade00f9cb51f1b0140557d329d56844c
#}

#variant sortloot {
#        patch_sites-append http://www.netsonic.fi/~walker/nh/
#        patchfiles-append sortloot-343.diff
#        checksums-append sortloot-343.diff md5 ade00f9cb51f1b0140557d329d56844c
#}

